@@ -1,5 +1,7 @@
 from ilexconf import Config
 
+# from ilexconf.tests.debug import debug
+
 import json
 import pytest
 
@@ -19,6 +21,16 @@ MERGED = {
     "d1": False,
 }
 
+WITH_LISTS = {
+    "database": {
+        "connections": [
+            {"host": "1.2.3.4", "port": 5000},
+            {"host": "4.5.6.7", "port": 8080},
+        ],
+        "params": [["kw1", "kw2", 3], {"key": "value of key"}],
+    }
+}
+
 
 def test_empty_config():
     cfg = Config()
@@ -41,7 +53,12 @@ def test_nested_access():
     assert cfg["d1"] is False
 
 
-def test_merge():
+def test_simple_merge():
+    cfg = Config(Config({"c1": 1, "C2": 2, "c3": 3}), Config({"c3": "val"}))
+    assert cfg.as_dict() == {"c1": 1, "C2": 2, "c3": "val"}
+
+
+def test_nested_merge():
     cfg = Config(NESTED, MERGABLE)
     # "val" has replaced 3 as value for a1.b1.c3
     assert cfg.a1.b1.c3 == "val"
@@ -50,6 +67,12 @@ def test_merge():
     assert cfg.a1.b1.c1 == 1
 
 
+def test_list():
+    cfg = Config(WITH_LISTS)
+    print(cfg)
+    assert cfg.as_dict() == WITH_LISTS
+
+
 def test_as_dict():
     cfg = Config(NESTED, MERGABLE)
     d = cfg.as_dict()
